CryptoExtensions class

Singleton extension class for cryptographic key operations.

Centralizes access to crypto helpers (symmetric/private/public key helpers) using Dart extensions for clean, modular access.

Available extensions

Constructors

CryptoExtensions()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
helper GeneralCryptoHelper?

Available on CryptoExtensions, provided by the GeneralCryptoExtension extension

getter/setter pair
privateHelper PrivateKeyHelper?

Available on CryptoExtensions, provided by the PrivateKeyExtension extension

getter/setter pair
publicHelper PublicKeyHelper?

Available on CryptoExtensions, provided by the PublicKeyExtension extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symmetricHelper SymmetricKeyHelper?

Available on CryptoExtensions, provided by the SymmetricKeyExtension extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited