DocumentHelper class abstract interface

Helper interface for document management in the account system.

Manages Document factories (by type) and provides core functionality for:

  • Creating entity documents (extended account information)
  • Parsing raw document data into strongly-typed Document instances

Documents (e.g., Visa, Bulletin) contain extended information about an entity beyond core metadata (profile, group info, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDocument(String docType, {String? data, TransportableData? signature}) Document
Creates a custom entity document with specified parameters.
getDocumentFactory(String docType) DocumentFactory?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDocument(Object? doc) Document?
Parses raw document data into a strongly-typed Document instance.
setDocumentFactory(String docType, DocumentFactory factory) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited