FormatExtensions class

Singleton extension class for message format operations.

Centralizes access to format helpers (like TransportableDataHelper) using Dart extensions for clean, modular access.

Available extensions

Constructors

FormatExtensions()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tedHelper TransportableDataHelper?

Available on FormatExtensions, provided by the TransportableDataExtension extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited