PrivateKeyHelper class abstract interface

Helper interface for private key management.

Manages private key factories (by algorithm) and provides methods to generate new private keys and parse raw private key data into PrivateKey instances.

Private keys are used for signing data or decrypting data encrypted with the public key.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generatePrivateKey(String algorithm) PrivateKey?
Generates a new private key for the specified algorithm.
getPrivateKeyFactory(String algorithm) PrivateKeyFactory?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsePrivateKey(Object? key) PrivateKey?
Parses raw private key data into a PrivateKey instance.
setPrivateKeyFactory(String algorithm, PrivateKeyFactory factory) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited