generatePrivateKey abstract method

PrivateKey? generatePrivateKey(
  1. String algorithm
)

Generates a new private key for the specified algorithm.

Creates a cryptographically secure random private key for the given algorithm.

@param algorithm - Name of the asymmetric algorithm (e.g., "RSA", "ECC")

@return New private key (null if algorithm is unsupported)

Implementation

PrivateKey? generatePrivateKey(String algorithm);