SymmetricKeyHelper class abstract interface

Helper interface for symmetric key management.

Manages symmetric key factories (by algorithm) and provides methods to generate new symmetric keys and parse raw key data into SymmetricKey instances.

Symmetric keys are used for encrypting/decrypting message content (AES, DES, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateSymmetricKey(String algorithm) SymmetricKey?
Generates a new symmetric key for the specified algorithm.
getSymmetricKeyFactory(String algorithm) SymmetricKeyFactory?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseSymmetricKey(Object? key) SymmetricKey?
Parses raw key data into a SymmetricKey instance.
setSymmetricKeyFactory(String algorithm, SymmetricKeyFactory factory) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited