TransportableDataHelper class abstract interface

Helper interface for processing TransportableData (TED) objects.

Provides core functionality for managing TransportableData factories and parsing raw data objects into strongly-typed TransportableData instances.

TransportableData is used to encapsulate serializable binary/data content in message payloads.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTransportableDataFactory() TransportableDataFactory?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseTransportableData(Object? ted) TransportableData?
Parses a raw object into a TransportableData instance.
setTransportableDataFactory(TransportableDataFactory factory) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited