AccountExtensions class
Singleton extension class for account system operations.
Provides a unified entry point for accessing all account-related helpers, ensuring consistent management of account components (Address/ID/Meta/Document).
- Available extensions
Constructors
- AccountExtensions()
-
factory
Properties
- addressHelper ↔ AddressHelper?
-
Available on AccountExtensions, provided by the AddressExtension extension
getter/setter pair - docHelper ↔ DocumentHelper?
-
Available on AccountExtensions, provided by the DocumentExtension extension
getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- helper ↔ GeneralAccountHelper?
-
Available on AccountExtensions, provided by the GeneralAccountExtension extension
getter/setter pair - idHelper ↔ IDHelper?
-
Available on AccountExtensions, provided by the IDExtension extension
getter/setter pair - metaHelper ↔ MetaHelper?
-
Available on AccountExtensions, provided by the MetaExtension extension
getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited