Helper interface for address management in the account system.
Manages address factories and provides core functionality for:
- Parsing raw address data into strongly-typed Address instances
- Generating valid addresses from entity metadata (Meta)
Addresses are unique identifiers for entities(user/group) in the network.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateAddress(
Meta meta, int? network) → Address - Generates a valid Address from entity metadata and network identifier.
-
getAddressFactory(
) → AddressFactory? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseAddress(
Object? address) → Address? - Parses a raw object into a strongly-typed Address instance.
-
setAddressFactory(
AddressFactory factory) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited